<?php
/**
 * Polaris Functions
 * 
 * @package	polaris
 * @since   1.0
 * @author  XinThemes
 * @license GPL v3 or later
 * @link    http://www.xinthemes.com/
 */
// Global variable for content width
if ( ! isset( $content_width ) ) 
	$content_width = 690; // pixels
//Load Core functions
require_once( get_template_directory() . '/inc/theme-settings.php' );
require_once( get_template_directory() . '/xinwp/core-functions.php' );
	
add_action( 'after_setup_theme', 'polaris_setup' );
if ( ! function_exists( 'polaris_setup' ) ):
function polaris_setup() {						
	register_nav_menus( array(
		'top-bar' => __( 'Top Menu' , 'polaris' ),
		'section' => __( 'Section Menu' , 'polaris' ),
		'footer' => __( 'Footer Menu', 'polaris' ),
	));
	// Custom Header
	$custom_header_support = array(
		'default-image'		=> get_template_directory_uri() . '/images/header/header1.jpg',
		'flex-width'        => true,
		'flex-height'		=> true,
	    'header-text'		=> true,
		'default-text-color' => '000000',		
		'width' 			=> apply_filters( 'xinwp_header_image_width', 300 ),
		'height' 			=> apply_filters( 'xinwp_header_image_height', 110 ),
		// Callback for styling the header.
		'wp-head-callback' => 'xinwp_header_style_cb',
		// Callback for styling the header preview in the admin.
		'admin-head-callback' => 'xinwp_admin_header_style_cb',
		// Callback used to display the header preview in the admin.
		'admin-preview-callback' => 'xinwp_admin_header_image_cb',
	);
	add_theme_support( 'custom-header', $custom_header_support );	

	register_default_headers( array(
		'header1' => array(
			'url' => '%s/images/header/header1.jpg',
			'thumbnail_url' => '%s/images/header/header1-thumb.jpg',
			'description' => __( 'Header 1', 'polaris' )
		),
		'header2' => array(
			'url' => '%s/images/header/header2.jpg',
			'thumbnail_url' => '%s/images/header/header2-thumb.jpg',
			'description' => __( 'Header 2', 'polaris' )
		),
	) ); 

	add_image_size( 'polaris-header', 1080, 281, true);
}
endif;

function polaris_header_image_width() {
	return 1080;	
}
add_filter( 'xinwp_header_image_width', 'polaris_header_image_width' );

function polaris_header_image_height() {
	return 281;	
}
add_filter( 'xinwp_header_image_height', 'polaris_header_image_height' );

if ( ! function_exists( 'polaris_header_image' ) ) :
function polaris_header_image( $header_image, $size = 'full' ) {
	$html = '';
//	$header_image = get_header_image();
	if ( ! empty( $header_image ) ) {
		if( function_exists( 'get_custom_header' ) ) {
			$header_width = get_custom_header() -> width;
			$header_height = get_custom_header() -> height;
		}
		else {
			$header_width = HEADER_IMAGE_WIDTH;
			$header_height = HEADER_IMAGE_HEIGHT;				
		}
		if ( 'full' != $size ) {
			$ratio = $size / $header_height;
			$header_height = (int) $header_height * $ratio;
			$header_width = (int) $header_width  * $ratio;				 
		}
		$html = '<img src="' . $header_image . '" width="';
		$html .= $header_width . '" height="' . $header_height;
		$html .= '" alt="' . get_bloginfo( 'name') . '" />';
	}	
	echo apply_filters( 'polaris_header_image', $html );
}
endif;

if  ( ! function_exists( 'polaris_branding' ) ) :
function polaris_branding() {
?>
<div id="branding">
<?php
	global $xinwp_options;
	xinwp_header_branding(); //Action Hooks
	get_sidebar( 'header' );
	$flag = false;
	if ( 1 == $xinwp_options['headerstyle'])
		$flag = polaris_header_slider();
	if ( ! $flag && 3 == $xinwp_options['headerstyle'] && is_single() )
		$flag = polaris_featured_image();		
	if ( ! $flag ) {
		$header_image = get_header_image();
		if ( ! empty( $header_image ) )
			polaris_header_image( $header_image );
?>
		<div class="site-title">
			<h3 id="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h3>
			<h3 id="site-description"><?php bloginfo( 'description' ); ?></h3>
		</div>
<?php
	} ?>
</div>
<?php
}
endif;

/********************************************
* Dispay Featured Image 
*********************************************/
if ( ! function_exists( 'polaris_featured_image' ) ) :
function polaris_featured_image() {
	if ( has_post_thumbnail() ) {
		the_post_thumbnail( 'polaris-header', array( 'class' => 'polaris-header' ) );
		return true;
	}
	else
		return false;
}
endif;

if ( ! function_exists( 'polaris_header_slider' ) ) :
// Display Header Slider
function polaris_header_slider() {
	global $xinwp_options;
	$post_pp = -1; // All Posts
	if ( 1 == $xinwp_options['fp_option']  && 0 == $xinwp_options['fp_category'] )
		$post_pp = 10;
	$args = array(
			'post_type' => 'post',
			'post_status' => 'publish',
			'posts_per_page' => $post_pp,
			'ignore_sticky_posts' => 1,
			'no_found_rows' => 1
			);	
	if ( $xinwp_options['fp_category'] > 0 && 1 == $xinwp_options['fp_option'] )
		$args['category__in'] = $xinwp_options['fp_category'];
	elseif ( 2 == $xinwp_options['fp_option'] ) {
		$args['meta_query'] = array(
       		array(	'key' => '_polaris_featured',
           			'value' => 1,
          			'compare' => 'IN' ) );
	}
	$count = 0;
	$featured = new WP_Query( $args );
	while ( $featured->have_posts() ) {
		$featured->the_post();
		if ( has_post_thumbnail() ) { // Featured
			if ( 0 == $count ) {
				echo '<ul id="header-slider" class="">';
			}
			echo '<li>';
			echo '<a href="' . get_permalink() . '">';			
			the_post_thumbnail( 'polaris-header', array(  'title' => get_the_title() ) );
			echo '</a></li>';
			$count += 1;
		}

	}
	wp_reset_postdata();
	if ( $count > 0 ) {
		echo '</ul>';
		return true;		
	}
	else
		return false;
}
endif;

function polaris_body_classes( $classes ) {
	global $xinwp_options, $xinwp_layout;
			
	if ( ! is_single() )
		$classes[] = 'multi';
	elseif ( 2 == $xinwp_layout )
		$classes[] = 'fullscreen';
	return $classes;
}
add_filter( 'body_class', 'polaris_body_classes' );

function polaris_scripts_method() {	
	global $xinwp_options;

	$theme_uri = get_template_directory_uri();		

	wp_enqueue_style('polaris', $theme_uri . '/css/polaris.css', array( 'xinwp-foundation' ), XINWP_VERSION);
	$child_pre = array( 'polaris' );
	// Load Scheme CSS
	if ( ! empty( $xinwp_options['schemecss'] ) ) {
		wp_enqueue_style('polaris-scheme', $xinwp_options['schemecss'], $child_pre, XINWP_VERSION );
		$child_pre[] = 'polaris-scheme';		
	}
	//Load child theme's style.css
    if ( $theme_uri != get_stylesheet_directory_uri() )
		wp_enqueue_style('polaris-child', get_stylesheet_uri(), $child_pre, XINWP_VERSION );

	$polaris_dep = array( 'foundation', 'xinwp-bxslider' );
	// Page Template specific
	if ( is_page_template( 'pages/portfolio.php' ) ) {
		wp_enqueue_script( 'infinite-scroll' , $theme_uri . '/js/jquery.infinitescroll.min.js', array( 'jquery-masonry' ), '2.0', true );	
		$polaris_dep[] = 'infinite-scroll';
	}		
	//Scripts
	wp_enqueue_script( 'xinwp-bxslider' );
	wp_enqueue_script( 'polaris' , $theme_uri . '/js/polaris.js', $polaris_dep, XINWP_VERSION, true );
	wp_localize_script( 'polaris', 'polarisData', array( 'menuName' => xinwp_menu_name( 'section' ), 'mode' => $xinwp_options['fp_effect'] ) );
}
if ( ! is_admin() )
	add_action( 'wp_enqueue_scripts', 'polaris_scripts_method' ); 

function polaris_default_options() {
	$defaults = array(
		'currenttab' => 0,	
		'headerstyle' => 2,
		'fp_option' => 1,
		'fp_category' => 0,
		'fp_effect' => 'slide',
		'gridwidth' => 1080,
		'content' => 8,
		'sidebar1' => 2,
		'sidebar2' => 2,
		'sidebarpos' => 1,
		'sidebarresp' => 0,
		'respbp' => 960,
		'column_home1' => 4,
		'column_home2' => 4,
		'column_home3' => 4,
		'column_home4' => 0,
		'column_home5' => 0,
		'column_footer1' => 4,
		'column_footer2' => 4,
		'column_footer3' => 4,
		'column_footer4' => 0,
		'brandname' => 'Your LOGO',
		'brandlogo' => '',
		'brandurl' => '',
		'menupos' => 'right',
		'polaris_inline_css' => '',
		'polaris_scheme_css' => '',
		'bodyfont' => 0,
		'sitetitlefont' => 0,
		'sitedescfont' => 0,
		'entrytitlefont' => 0,
		'headingfont' => 0,
		'widgettitlefont' => 0,
		'sidebarfont' => 0,
		'footerfont' => 0,
		'mainmenufont' => 0,
		'otherfont1' => '',
		'otherfont2' => '',
		'otherfont3' => '',
		'otherfont4' => '',
		'colorscheme' => '0',
		'schemecss' => '',
	);
	return $defaults;
}
add_filter( 'xinwp_default_options', 'polaris_default_options' );

function polaris_custom_css() {
	global $xinwp_options;

	echo '<!-- Custom CSS Styles -->' . "\n";
    echo '<style type="text/css" media="screen">' . "\n";
    if ( ! empty( $xinwp_options['polaris_scheme_css'] ) )
		echo $xinwp_options['polaris_scheme_css'] . "\n";
    if ( ! empty( $xinwp_options['polaris_inline_css'] ) )
		echo $xinwp_options['polaris_inline_css'] . "\n";
	echo '</style>' . "\n";
}
add_action( 'wp_head', 'polaris_custom_css' );

require_once( get_template_directory() . '/scheme/scheme.php' );
if ( is_admin() ) {
	require_once( get_template_directory() . '/inc/theme-options.php' );
}

$xinwp_options = xinwp_get_options(); //Global Theme Options
