<?php 
if ( ! defined( 'ABSPATH' ) ) exit;
/**
 * Theme Options
 *
 * @package polaris
 * @since polaris 1.0
 */
add_action( 'admin_init', 'polaris_options_init' );
add_action( 'admin_menu', 'polaris_theme_options_admin_menu' );
function polaris_admin_enqueue_scripts( $hook_suffix ) {
	global $xinwp_options, $xinwp_fonts;
	$xinwp_options = xinwp_get_options();
	
	$template_uri = get_template_directory_uri();
	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_style( 'xinwp-theme-options', $template_uri . '/xinwp/css/theme-options.css', false, '1.0' );
	wp_enqueue_script( 'xinwp-theme-options', $template_uri . '/xinwp/js/theme-options.js', array('jquery','wp-color-picker', 'jquery-ui-sortable'), '1.0' );
	
	$xinwp_fonts = xinwp_fonts_array();
	foreach ( $xinwp_fonts as $font ) {
		if ( ! empty( $font['url'] ) )
			wp_enqueue_style( str_replace(' ', '', $font['label'] ), $font['url'], false, '1.0' );
	}
}
add_action( 'admin_print_styles-appearance_page_theme_options', 'polaris_admin_enqueue_scripts' );

function polaris_options_init() {
    register_setting( 'polaris_options', 'polaris_theme_options', 'polaris_theme_options_validate' );
}

function polaris_theme_options_admin_menu() {
    add_theme_page( __( 'Theme Options', 'polaris' ), __('Theme Options', 'polaris' ), 'edit_theme_options', 'theme_options', 'polaris_theme_options_display_page' );
}

function polaris_theme_options_array() {	
	global $xinwp_fonts;
	
	$theme_options = array(
		'currenttab'	=> array(
			'name'	=> 'currenttab',
			'type'	=> 'hidden',			
		),	
		'section_order'	=> array(
			'name'	=> 'section_order',
			'type'	=> 'hidden',			
		),
// Layout
		'gridwidth'	=> array(
			'name'	=> 'gridwidth',
			'label'	=> __( 'Grid Width', 'polaris' ),
			'type'	=> 'number',
			'desc'	=> __( 'Pixels', 'polaris' ),
		),
		'content'	=> array(
			'name'	=> 'content',
			'label'	=> __( 'Content', 'polaris' ),
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'sidebar1'	=> array(
			'name'	=> 'sidebar1',
			'label'	=> __( 'Sidebar 1', 'polaris' ),
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'sidebar2'	=> array(
			'name'	=> 'sidebar2',
			'label'	=> __( 'Sidebar 2', 'polaris' ),
			'type'	=> 'number',
			'desc' => __( 'Columns', 'polaris' ),
			'fieldonly'	=> '1',
		),
		'sidebarpos'	=> array(
			'name'	=> 'sidebarpos',
			'label'	=> __( 'Sidebar Position', 'polaris' ),
			'type'	=> 'radio',		
			'values' => array(
					array( 'key' => 1, 'label' => __( 'Right ', 'polaris' ) ),
					array( 'key' => 2, 'label' => __( 'Left ', 'polaris' ) ),
					array( 'key' => 3, 'label' => __( 'Left & Right ', 'polaris' ) ),
						),
			'helptext' => __( 'Note: For Left & Right layout, Blog Widget Area (Full) will not be used. The total columns must be 12.', 'polaris' ),
		),
		'sidebarresp'	=> array(
			'name'	=> 'sidebarresp',
			'label'	=> __( 'Responsive Sidebar', 'polaris' ),
			'type'	=> 'checkbox',
			'desc'  => __( 'Check to activate responsive sidebars when screen width below breakpoints', 'polaris' ),
		),
		'respbp'	=> array(
			'name'	=> 'respbp',
			'label'	=> __( 'Responsive Sidebar Breakpoint', 'polaris' ),
			'type'	=> 'number',
			'desc'  => __( 'minimum 960 pixels', 'polaris' ),
		),
		'column_home1'	=> array(
			'name'	=> 'column_home1',
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'column_home2'	=> array(
			'name'	=> 'column_home2',
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'column_home3'	=> array(
			'name'	=> 'column_home3',
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'column_home4'	=> array(
			'name'	=> 'column_home4',
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'column_home5'	=> array(
			'name'	=> 'column_home5',
			'type'	=> 'number',
			'desc' => __( 'Columns', 'xin' ),
			'fieldonly'	=> '1',
		),

		'column_footer1'	=> array(
			'name'	=> 'column_footer1',
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'column_footer2'	=> array(
			'name'	=> 'column_footer2',
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'column_footer3'	=> array(
			'name'	=> 'column_footer3',
			'type'	=> 'number',
			'fieldonly'	=> '1',
		),
		'column_footer4'	=> array(
			'name'	=> 'column_footer4',
			'type'	=> 'number',
			'desc' => __( 'Columns', 'polaris' ),
			'fieldonly'	=> '1',
		),
//Home Page
		'fp_option'	=> array(
			'name'	=> 'fp_option',
			'label'	=> __( 'Posts for Carousel', 'polaris' ),
			'type'	=> 'radio',
			'values' => array(
				array( 'key' => 1,
							   'label' => __( 'Featured Category', 'polaris' ) ),
				array( 'key' => 2,
							   'label' => __( 'Featured Posts', 'polaris' ) ),
						),		
		),
		'fp_effect'	=> array(
			'name'	=> 'fp_effect',
			'label'	=> __( 'Animation', 'polaris' ),
			'type'	=> 'radio',
			'values' => array(
				array( 'key' => 'horizontal',
							   'label' => __( 'Slide', 'polaris' ) ),
				array( 'key' => 'fade',
							   'label' => __( 'Fade', 'polaris' ) ),
						),		
		),
		'fp_category'	=> array(
			'name'	=> 'fp_category',
			'label'	=> __( 'Featured Category', 'polaris' ),
			'type'	=> 'category',	
		),
// Header
		'headerstyle'	=> array(
			'name'	=> 'headerstyle',
			'label'	=> __( 'Header Style', 'polaris' ),
			'type'	=> 'radio',
			'values' => array(
				array(	'key' => 1,
						'label' => __( 'Slider', 'polaris' ) ),
				array(	'key' => 2,
						'label' => __( 'Header Image', 'polaris' ) ),
				array(	'key' => 3,
						'label' => __( 'Header/Featured Image', 'polaris' ) ),
						),	
		),
// Top Bar
		'brandname'	=> array(
			'name'	=> 'brandname',
			'label'	=> __( 'Brand Name', 'polaris' ),
			'type'	=> 'text',
			'helptext'	=> __( 'Leave it blank to display Brand Logo.', 'polaris' ),
		),
		'brandlogo'	=> array(
			'name'	=> 'brandlogo',
			'label'	=> __( 'Brand Logo', 'polaris' ),
			'type'	=> 'image',
			'helptext'	=> __( 'Enter URL of the uploaded image.', 'polaris' ),
		),
		'brandurl'	=> array(
			'name'	=> 'brandurl',
			'label'	=> __( 'Brand URL', 'polaris' ),
			'type'	=> 'url',
			'helptext'	=> __( 'Enter URL of the main brand site.', 'polaris' ),
		),
		'menupos'	=> array(
			'name'	=> 'menupos',
			'label'	=> __( 'Top Menu Position', 'polaris' ),
			'type'	=> 'radio',
			'values' => array(
				array( 'key' => 'left',
							   'label' => __( 'Left', 'polaris' ) ),
				array( 'key' => 'right',
							   'label' => __( 'Right', 'polaris' ) ),
						),		
		),
// Skins
		'colorscheme'	=> array(
			'name'	=> 'colorscheme',
			'label'	=> __( 'Color Scheme', 'polaris' ),
			'type'	=> 'select',
			'values' => polaris_scheme_options(),
		),
		'schemecss'	=> array(
			'name'	=> 'schemecss',
			'type'	=> 'hidden',
		),
//Fonts
		'bodyfont'	=> array(
			'name'	=> 'bodyfont',
			'label'	=> __( 'Body / Paragraph', 'polaris' ),
			'type'	=> 'font',	
			'values' => $xinwp_fonts,
		),
		'sitetitlefont'	=> array(
			'name'	=> 'sitetitlefont',
			'label'	=> __( 'Site Title', 'polaris' ),
			'type'	=> 'font',	
			'values' => $xinwp_fonts,
		),
		'sitedescfont'	=> array(
			'name'	=> 'sitedescfont',
			'label'	=> __( 'Site Description', 'polaris' ),
			'type'	=> 'font',	
			'values' => $xinwp_fonts,
		),
		'entrytitlefont'	=> array(
			'name'	=> 'entrytitlefont',
			'label'	=> __( 'Post/Page Title', 'polaris' ),
			'type'	=> 'font',
			'values' => $xinwp_fonts,
		),
		'headingfont'	=> array(
			'name'	=> 'headingfont',
			'label'	=> __( 'Heading (H1 - H6)', 'polaris' ),
			'type'	=> 'font',
			'values' => $xinwp_fonts,
		),
		'sidebarfont'	=> array(
			'name'	=> 'sidebarfont',
			'label'	=> __( 'Sidebar', 'polaris' ),
			'type'	=> 'font',
			'values' => $xinwp_fonts,
		),
		'widgettitlefont'	=> array(
			'name'	=> 'widgettitlefont',
			'label'	=> __( 'Widget Title', 'polaris' ),
			'type'	=> 'font',
			'values' => $xinwp_fonts,
		),
		'footerfont'	=> array(
			'name'	=> 'footerfont',
			'label'	=> __( 'Footer', 'polaris' ),
			'type'	=> 'font',
			'values' => $xinwp_fonts,
		),
		'mainmenufont'	=> array(
			'name'	=> 'mainmenufont',
			'label'	=> __( 'Main Menu', 'polaris' ),
			'type'	=> 'font',
			'values' => $xinwp_fonts,
		),

		'otherfont1'	=> array(
			'name'	=> 'otherfont1',
			'label'	=> __( 'Google Font 1', 'polaris' ),
			'type'	=> 'text',
		),
		'otherfont2'	=> array(
			'name'	=> 'otherfont2',
			'label'	=> __( 'Google Font 2', 'polaris' ),
			'type'	=> 'text',
		),
		'otherfont3'	=> array(
			'name'	=> 'otherfont3',
			'label'	=> __( 'Google Font 3', 'polaris' ),
			'type'	=> 'text',
		),
		'otherfont4'	=> array(
			'name'	=> 'otherfont4',
			'label'	=> __( 'Google Font 4', 'polaris' ),
			'type'	=> 'text',
			'helptext' => 'Enter Font Name only, e.g. Open Sans',	
		),
// Custom CSS
		'polaris_inline_css'	=> array(
			'name'	=> 'polaris_inline_css',
			'label'	=> __( 'Custom CSS Style', 'polaris' ),
			'type'	=> 'textarea',
			'row'   => 40,
		),
		'polaris_scheme_css'	=> array(
			'name'	=> 'polaris_scheme_css',
			'type'	=> 'hidden',
		),
	);
	return apply_filters( 'xinwp_options_array', $theme_options );
}

function polaris_theme_options_display_page() {
	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;
?>
    <div class="wrap">
<?php	screen_icon();
  		echo "<h2>" . __('Polaris Theme Options', 'polaris') . "</h2>";
		if ( false !== $_REQUEST['settings-updated'] ) { ?>
			<div class="updated fade"><p><strong><?php _e('Options Saved', 'polaris'); ?></strong></p></div>
<?php	} ?>
		<p><a class="btn btn-primary" href="<?php _e('http://xinthemes.com/docs/','polaris'); ?>" target="_blank"><strong><?php _e('Documentation','polaris'); ?></strong></a>&nbsp;&nbsp;
		<a class="btn btn-success" href="<?php _e('http://xinthemes.com/support/','polaris'); ?>" target="_blank"><strong><?php _e('Support Forum','polaris'); ?></strong></a>&nbsp;&nbsp;
		<a class="btn btn-info" href="<?php _e('http://xinthemes.com/donate/','polaris'); ?>" target="_blank"><strong><?php _e('Donate','polaris'); ?></strong></a></p>
    <form method="post" action="options.php">
<?php
	global $xinwp_theme_options, $xinwp_options;
	
	$xinwp_theme_options = polaris_theme_options_array();
	$xinwp_options = xinwp_get_options();
	settings_fields( 'polaris_options' );
?>
	<div id="xin-wrapper" class="container_12">
		<input id="save-button" type="submit" class="button-primary" value="<?php _e('Save Options','polaris'); ?>" />
	<div id="xin-tabs">
		<a><?php _e('Layout','polaris'); ?></a>
		<a><?php _e('Scheme','polaris'); ?></a>
		<a><?php _e('Fonts','polaris'); ?></a>
		<a><?php _e('Custom CSS','polaris'); ?></a>
<?php //Allow child them to add options.
		do_action( 'xinwp_options_tab_link' ); ?>
	</div>
<?php
/******************************************************************
*  Theme Options related to site layout
******************************************************************/
?>
	<div class="xin-pane clearfix"><div class="grid_12">
	<h3><?php _e('Site Layout (12 Columns)','polaris'); ?></h3>	
<?php	xinwp_option_display( 'gridwidth' ); ?>
	<div class="grid_3 alpha">
		<p><b><?php _e('Content and Sidebar Width', 'polaris'); ?></b></p>
	</div>
	<div class="grid_9">
<?php
		xinwp_option_display( 'content' );
		xinwp_option_display( 'sidebar1' );
		xinwp_option_display( 'sidebar2' );
?>
	</div><div class="clear"></div>
<?php
		xinwp_option_display( 'sidebarpos' );
		xinwp_option_display( 'sidebarresp' );
		xinwp_option_display( 'respbp' );
?>
	<div class="grid_3 alpha">
		<p><b><?php _e('Home Widget Area Width', 'xin'); ?></b></p>
	</div>
	<div class="grid_9">
<?php
		xinwp_option_display( 'column_home1' );
		xinwp_option_display( 'column_home2' );
		xinwp_option_display( 'column_home3' );
		xinwp_option_display( 'column_home4' );
		xinwp_option_display( 'column_home5' );
?>
	</div><div class="clear"></div>
	<div class="grid_3 alpha">
		<p><b><?php _e('Footer Widget Area Width', 'polaris'); ?></b></p>
	</div>
	<div class="grid_9">
<?php
		xinwp_option_display( 'column_footer1' );
		xinwp_option_display( 'column_footer2' );
		xinwp_option_display( 'column_footer3' );
		xinwp_option_display( 'column_footer4' );
?>
	</div><div class="clear"></div>
		<h3><?php _e('Header','polaris'); ?></h3>
<?php	xinwp_option_display( 'headerstyle' );
		xinwp_option_display( 'fp_option' );
		xinwp_option_display( 'fp_category' );
		xinwp_option_display( 'fp_effect' );
?>
		<h3><?php _e('Top Bar','polaris'); ?></h3>
<?php	xinwp_option_display( 'brandname' );
		xinwp_option_display( 'brandlogo' );
		xinwp_option_display( 'brandurl' );
		xinwp_option_display( 'menupos' );	
		do_action( 'xinwp_options_tab_layout' ); ?>			
	</div></div>
<?php
/******************************************************************
*  Theme Options: Scheme
******************************************************************/
?>
	<div class="xin-pane clearfix"><div class="grid_12">
<?php	xinwp_option_display( 'colorscheme' ); ?>
		<p><?php _e('Change Background Image or Color : ','polaris'); printf( __('<a href="%s">Click here</a>.', 'polaris'), admin_url('themes.php?page=custom-background')); ?></p>
<?php	
		do_action( 'xinwp_options_tab_scheme' );
?>
	</div></div>	
<?php
/**************************************
* Theme Options - Fonts  *
**************************************/
?>
	<div class="xin-pane clearfix"><div class="grid_12">
	<p><?php _e( 'You do not need to select font for each element. For example. Body, paragraph and heading define the general fonts used. <span style="color:blue;font-weight:bold;">Please note that blue indicates webfonts (e.g Google Fonts) which may require additional load time.</span>', 'polaris' ); ?></p>
<?php 
		xinwp_option_display( 'bodyfont' );
		xinwp_option_display( 'headingfont' );
?>
	<hr>
<?php
		xinwp_option_display( 'sitetitlefont' );
		xinwp_option_display( 'sitedescfont' );
?>
	<hr>
<?php
		xinwp_option_display( 'entrytitlefont' );
		xinwp_option_display( 'widgettitlefont' );
		xinwp_option_display( 'sidebarfont' );
		xinwp_option_display( 'mainmenufont' );
		xinwp_option_display( 'footerfont' );
?>
	<h3><?php _e( 'Additional Google Fonts', 'polaris' ); ?></h3>
<?php
		xinwp_option_display( 'otherfont1' );
		xinwp_option_display( 'otherfont2' );
		xinwp_option_display( 'otherfont3' );
		xinwp_option_display( 'otherfont4' );
		do_action( 'xinwp_options_tab_fonts' );
?>
	</div></div>
<?php
/******************************************************************
*  Custom CSS
******************************************************************/
?>
	<div class="xin-pane clearfix"><div class="grid_12">
<?php
		xinwp_option_display( 'polaris_inline_css' );	
?>
	</div></div>
<?php
/******************************************************************
*  Child Theme Options
******************************************************************/
	do_action( 'xinwp_options_tab_page' );
	xinwp_option_display( 'currenttab');
    xinwp_option_display( 'schemecss' );
	xinwp_option_display( 'polaris_scheme_css' );
?>
	<p><input id="save-button-bottom" type="submit" class="button-primary" value="<?php _e( 'Save Options', 'polaris' ); ?>" /></p>
	</div><!-- polaris-wrapper -->
    </form>
    </div><!-- wrap -->
<?php
}
		
function polaris_theme_options_validate( $input ) {
	$theme_options = polaris_theme_options_array();
	foreach ( $theme_options as $theme_option ) {
		switch ( $theme_option['type'] ) {
			case 'checkbox':
				if ( ! isset( $input[ $theme_option['name'] ] ) )
					$input[$theme_option['name']] = null;
		    	$input[ $theme_option['name'] ] = ( $input[ $theme_option['name'] ] == 1 ? 1 : 0 );
				break;
			case 'text':
			case 'textarea':
				$input[ $theme_option['name'] ] = wp_kses_stripslashes( $input[ $theme_option['name'] ] );
				break;
			case 'number':	
				$input[ $theme_option['name'] ] = intval( $input[ $theme_option['name'] ] );	
				break;				
			case 'url':	
			case 'image':	
				$input[ $theme_option['name'] ] = esc_url_raw( $input[$theme_option['name'] ] );	
				break;
			case 'color':
				$input[ $theme_option['name'] ] = sanitize_text_field( $input[ $theme_option['name'] ] );	
				break;
		}
	}
	if ( $input['respbp'] < 960 )
		$input['respbp'] = 960;
	$input['polaris_scheme_css'] = polaris_scheme_css( $input );
	//Update Scheme Options
	$options = xinwp_get_options();
	if ( $input['colorscheme'] != $options['colorscheme'] ) {
		$scheme = $theme_options['colorscheme']['values'][ $input['colorscheme'] ];
		$input['schemecss'] = $scheme['css']; 
		foreach ( $scheme['options'] as $scheme_options )
			$input[ $scheme_options['name'] ] = $scheme_options['value'];
	}
	return $input;
}

function polaris_scheme_css($input) {
	$xinwp_fonts = xinwp_fonts_array();
	$css = '';
	if ( 1080 != $input['gridwidth'] ) {
		$css .= '.row, .contain-to-grid .top-bar {max-width: ' . $input['gridwidth'] . 'px; }' . "\n";
	}
	if ( 1 == $input['sidebarresp'] && 3 != $input['sidebarpos'] ) {
		if ( ( $input['content'] + $input['sidebar1'] + $input['sidebar2']) <= 12 ) {
			$pct = 100 / 12 * ( $input['sidebar1'] + $input['sidebar2'] );
			$pct = (int) $pct * 100000;
			$pct = $pct / 100000;
			$css .= '@media only screen and (min-width: 768px) ';
			$css .= 'and (max-width: ' . $input['respbp'] . 'px) {' . "\n";
			$css .= '#sidebar_one,#sidebar_two { width: ' . $pct;
			$css .= '%; border-right: none; }}' . "\n";
		}
	}
	if ( 1 == $input['sidebarresp'] ) {
		$pct = 50;
			$css .= '@media only screen and (min-width: 481px) ';
			$css .= 'and (max-width: 767px) {' . "\n";
		$css .= '#sidebar_one,#sidebar_two { width: ' . $pct;
		$css .= '%; }}' . "\n";		
	}

// Fonts
	if ( $input['bodyfont'] > 0 )
		$css .= 'body {font-family:' . $xinwp_fonts[ $input['bodyfont'] ]['family'] . ';}' . "\n";
	if ( $input['headingfont'] > 0 )
		$css .= 'h1, h2, h3, h4, h5, h6 {font-family:' . $xinwp_fonts[$input['headingfont']]['family'] . ';}' . "\n";
	if ( $input['entrytitlefont'] > 0 )
		$css .= '.entry-title {font-family:' . $xinwp_fonts[$input['entrytitlefont']]['family'] . ';}' . "\n";
	if ( $input['sitetitlefont'] > 0 )
		$css .= '#site-title {font-family:' . $xinwp_fonts[$input['sitetitlefont']]['family'] . ';}' . "\n";
	if ( $input['sitedescfont'] > 0 )
		$css .= '#site-description {font-family:' . $xinwp_fonts[$input['sitedescfont']]['family'] . ';}' . "\n";
	if ( $input['widgettitlefont'] > 0 )
		$css .= '.widget-title {font-family:' . $xinwp_fonts[$input['widgettitlefont']]['family'] . ';}' . "\n";
	if ( $input['sidebarfont'] > 0 )
		$css .= '.blog-widgets {font-family:' . $xinwp_fonts[$input['sidebarfont']]['family'] . ';}' . "\n";
	if ( $input['footerfont'] > 0 )
		$css .= '#footer {font-family:' . $xinwp_fonts[$input['footerfont']]['family'] . ';}' . "\n";
	if ( $input['mainmenufont'] > 0 )
		$css .= '#topbar {font-family:' . $xinwp_fonts[$input['mainmenufont']]['family'] . ';}' . "\n";
	return apply_filters( 'polaris_scheme_css', $css );
}

